@@ -1,5 +1,9 @@
 ;; Some Emacs customizations to make it work well within the Maemo environment.
 
+;; Hide menu bar and tool bar by default due to limited screen space
+(menu-bar-mode -1)
+(tool-bar-mode -1)
+
 ;; dired: Do not pass --dired option to ls (not supported by busybox ls)
 (setq dired-use-ls-dired nil)
 
